package QEMU::Manager::ISOImage;

use strict;
use warnings;

use base qw(Net::DBus::Object);
use Net::DBus::Exporter qw(com.redhat.qemu.manager.ISOImage);

use Config::Record;


sub new {
    my $class = shift;
    my $machine = shift;
    my $name = shift;
    my $self = $class->SUPER::new($machine,
				  "/isoimage/$name");

    $self->{name} = $name;
    $self->{configFile} = shift;
    $self->{config} = Config::Record->new();
    
    bless $self, $class;

    if (-f $self->{configFile}) {
	$self->load_config;
    }

    return $self;
}


dbus_method("load_config");
dbus_signal("config_loaded");
sub load_config {
    my $self = shift;
    
    $self->{config}->load($self->{configFile});
    $self->emit_signal("config_loaded");
}


dbus_method("save_config");
dbus_signal("config_saved");
sub save_config {
    my $self = shift;
    
    $self->{config}->save($self->{configFile});
    $self->emit_signal("config_saved");
}



dbus_method("get_name", [], ["string"]);
sub get_name {
    my $self = shift;
    return $self->{name};
}

sub get_config {
    my $self = shift;
    my $name = shift;
    my $default = shift;
    return $self->{config}->get($name, $default);
}


dbus_signal("config_changed", ["string"]);
sub set_config {
    my $self = shift;
    my $name = shift;
    my $value = shift;
    $self->{config}->set($name, $value);
    $self->emit_signal("config_changed", $name);
}


dbus_method("get_title", [], ["string"]);
sub get_title {
    my $self = shift;
    return $self->get_config("title", "ISO image " . $self->get_name());
}

dbus_method("set_title", ["string"]);
sub set_title {
    my $self = shift;
    my $title = shift;
    return $self->set_config("title", $title);
}

dbus_method("get_filename", [], ["string"]);
sub get_filename {
    my $self = shift;
    return $self->get_config("filename");
}

dbus_method("set_filename", ["string"]);
sub set_filename {
    my $self = shift;
    my $file = shift;
    return $self->set_config("filename", $file);
}

dbus_method("get_size", [], ["int32"]);
sub get_size {
    my $self = shift;
    if (-f $self->get_filename) {
	my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,
	    $atime,$mtime,$ctime,$blksize,$blocks)
	    = stat _;
	return $size / (1024*1024);
    }
    return 0;
}

