package QEMU::Manager::Snapshot;

use strict;
use warnings;

use base qw(Net::DBus::Object);
use Net::DBus::Exporter qw(com.redhat.qemu.manager.Snapshot);


sub new {
    my $class = shift;
    my $machine = shift;
    my $name = shift;
    my $self = $class->SUPER::new($machine,
				  "/snapshot/$name");

    $self->{name} = $name;
    $self->{config} = shift;
    
    bless $self, $class;

    return $self;
}


dbus_method("get_name", [], ["string"]);
sub get_name {
    my $self = shift;
    return $self->{name};
}

sub get_config {
    my $self = shift;
    my $name = shift;
    my $default = shift;
    return $self->{config}->get($name, $default);
}


dbus_signal("config_changed", ["string"]);
sub set_config {
    my $self = shift;
    my $name = shift;
    my $value = shift;
    $self->{config}->set($name, $value);
    $self->emit_signal("config_changed", $name);
}


dbus_method("get_creation_date", [], ["uint32"]);
sub get_creation_date {
    my $self = shift;
    return $self->get_config("date");
}

dbus_method("get_machine_serial", [], ["uint32"]);
sub get_machine_serial {
    my $self = shift;
    return $self->get_config("serial");
}

dbus_method("get_title", [], ["string"]);
sub get_title {
    my $self = shift;
    return $self->get_config("title", "Snapshot " . $self->get_creation_date);
}

dbus_method("set_title", ["string"]);
sub set_title {
    my $self = shift;
    my $title = shift;
    return $self->set_config("title", $title);
}

dbus_method("get_filename", [], ["string"]);
sub get_filename {
    my $self = shift;
    return $self->get_config("filename");
}

dbus_method("get_size", [], ["int32"]);
sub get_size {
    my $self = shift;
    if (-f $self->get_filename) {
	my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,
	    $atime,$mtime,$ctime,$blksize,$blocks)
	    = stat _;
	return $size / (1024*1024);
    }
    return 0;
}

